[PATCH v5 01/29] compiler: Rename host_build() to tools_build()

Simon Glass sjg at chromium.org
Sun Sep 26 03:43:14 CEST 2021


With the new TOOLS_LIBCRYPTO and some other changes, it seems that we are
heading towards calling this a tools build rather than a host build,
although of course it does happen on the host.

I cannot think of anything built by the host which cannot be described as
a tool, so rename this function.

Signed-off-by: Simon Glass <sjg at chromium.org>
---

Changes in v5:
- Add a new patch to rename host_build() to tools_build()

 common/image-fit.c |  8 ++++----
 common/image.c     | 12 ++++++------
 include/compiler.h |  5 +++--
 3 files changed, 13 insertions(+), 12 deletions(-)

diff --git a/common/image-fit.c b/common/image-fit.c
index 5a0a0cc2007..6f8e67e4158 100644
--- a/common/image-fit.c
+++ b/common/image-fit.c
@@ -509,7 +509,7 @@ void fit_image_print(const void *fit, int image_noffset, const char *p)
 
 	ret = fit_image_get_data_and_size(fit, image_noffset, &data, &size);
 
-	if (!host_build()) {
+	if (!tools_build()) {
 		printf("%s  Data Start:   ", p);
 		if (ret) {
 			printf("unavailable\n");
@@ -1845,7 +1845,7 @@ int fit_conf_get_node(const void *fit, const char *conf_uname)
 	if (conf_uname == NULL) {
 		/* get configuration unit name from the default property */
 		debug("No configuration specified, trying default...\n");
-		if (!host_build() && IS_ENABLED(CONFIG_MULTI_DTB_FIT)) {
+		if (!tools_build() && IS_ENABLED(CONFIG_MULTI_DTB_FIT)) {
 			noffset = fit_find_config_node(fit);
 			if (noffset < 0)
 				return noffset;
@@ -2093,7 +2093,7 @@ int fit_image_load(bootm_headers_t *images, ulong addr,
 	}
 
 	bootstage_mark(bootstage_id + BOOTSTAGE_SUB_CHECK_ARCH);
-	if (!host_build() && IS_ENABLED(CONFIG_SANDBOX)) {
+	if (!tools_build() && IS_ENABLED(CONFIG_SANDBOX)) {
 		if (!fit_image_check_target_arch(fit, noffset)) {
 			puts("Unsupported Architecture\n");
 			bootstage_error(bootstage_id + BOOTSTAGE_SUB_CHECK_ARCH);
@@ -2158,7 +2158,7 @@ int fit_image_load(bootm_headers_t *images, ulong addr,
 	}
 
 	/* perform any post-processing on the image data */
-	if (!host_build() && IS_ENABLED(CONFIG_FIT_IMAGE_POST_PROCESS))
+	if (!tools_build() && IS_ENABLED(CONFIG_FIT_IMAGE_POST_PROCESS))
 		board_fit_image_post_process(fit, noffset, &buf, &size);
 
 	len = (ulong)size;
diff --git a/common/image.c b/common/image.c
index 2f2fd052c50..66685b4ba99 100644
--- a/common/image.c
+++ b/common/image.c
@@ -460,11 +460,11 @@ int image_decomp(int comp, ulong load, ulong image_start, int type,
 			ret = -ENOSPC;
 		break;
 	case IH_COMP_GZIP:
-		if (!host_build() && CONFIG_IS_ENABLED(GZIP))
+		if (!tools_build() && CONFIG_IS_ENABLED(GZIP))
 			ret = gunzip(load_buf, unc_len, image_buf, &image_len);
 		break;
 	case IH_COMP_BZIP2:
-		if (!host_build() && CONFIG_IS_ENABLED(BZIP2)) {
+		if (!tools_build() && CONFIG_IS_ENABLED(BZIP2)) {
 			uint size = unc_len;
 
 			/*
@@ -478,7 +478,7 @@ int image_decomp(int comp, ulong load, ulong image_start, int type,
 		}
 		break;
 	case IH_COMP_LZMA:
-		if (!host_build() && CONFIG_IS_ENABLED(LZMA)) {
+		if (!tools_build() && CONFIG_IS_ENABLED(LZMA)) {
 			SizeT lzma_len = unc_len;
 
 			ret = lzmaBuffToBuffDecompress(load_buf, &lzma_len,
@@ -487,7 +487,7 @@ int image_decomp(int comp, ulong load, ulong image_start, int type,
 		}
 		break;
 	case IH_COMP_LZO:
-		if (!host_build() && CONFIG_IS_ENABLED(LZO)) {
+		if (!tools_build() && CONFIG_IS_ENABLED(LZO)) {
 			size_t size = unc_len;
 
 			ret = lzop_decompress(image_buf, image_len, load_buf, &size);
@@ -495,7 +495,7 @@ int image_decomp(int comp, ulong load, ulong image_start, int type,
 		}
 		break;
 	case IH_COMP_LZ4:
-		if (!host_build() && CONFIG_IS_ENABLED(LZ4)) {
+		if (!tools_build() && CONFIG_IS_ENABLED(LZ4)) {
 			size_t size = unc_len;
 
 			ret = ulz4fn(image_buf, image_len, load_buf, &size);
@@ -503,7 +503,7 @@ int image_decomp(int comp, ulong load, ulong image_start, int type,
 		}
 		break;
 	case IH_COMP_ZSTD:
-		if (!host_build() && CONFIG_IS_ENABLED(ZSTD)) {
+		if (!tools_build() && CONFIG_IS_ENABLED(ZSTD)) {
 			struct abuf in, out;
 
 			abuf_init_set(&in, image_buf, image_len);
diff --git a/include/compiler.h b/include/compiler.h
index 6b0d3bf5374..8cf11792e24 100644
--- a/include/compiler.h
+++ b/include/compiler.h
@@ -155,11 +155,12 @@ typedef unsigned long int uintptr_t;
 #endif
 
 /**
  * host_build() - check if we are building for the host
  *
  * @return true if building for the host, false if for a target
  */
-static inline bool host_build(void) {
+static inline bool tools_build(void)
+{
 #ifdef USE_HOSTCC
 	return true;
 #else
@@ -155,11 +155,12 @@ typedef unsigned long int uintptr_t;
 
 /**
- * host_build() - check if we are building for the host
+ * tools_build() - check if we are building host tools
  *
  * @return true if building for the host, false if for a target
-- 
2.33.0.685.g46640cef36-goog



More information about the U-Boot mailing list